<?php
namespace Pelecardwc;

// require 'GetCurrency.php';
// require 'RequestIframe.php';

function get_my_account_iframe_url( Gateway $gateway ) {
	$args = apply_filters( 'wppc/my_account/iframe_args', [
		'terminal' => $gateway->wppc_terminal(),
		'user' => $gateway->wppc_username(),
		'password' => $gateway->wppc_password(),
		'GoodURL' => wc_get_endpoint_url( 'payment-methods' ),
		'ErrorURL' => wc_get_endpoint_url( 'payment-methods' ),
		'CancelURL' => 'yes' === $gateway->get_option( 'cancel_button' ) ? wc_get_endpoint_url( 'payment-methods' ) : '',
		'ActionType' => 'J2',
		'Currency' => get_currency(),
		'Total' => 100,
		'FreeTotal' => 'yes' === $gateway->get_option( 'free_total' ),
		'CreateToken' => true,
		'Language' => $gateway->get_option( 'language' ),
		'CardHolderName' => $gateway->get_option( 'card_holder_name' ),
		'CustomerIdField' => $gateway->get_option( 'customer_id_field' ),
		'Cvv2Field' => $gateway->get_option( 'cvv2_field' ),
		'SplitCCNumber' => 'yes' === $gateway->get_option( 'split_cc_number' ),
		'FeedbackOnTop' => true,
		'FeedbackDataTransferMethod' => 'POST',
		'MaxPayments' => 1,
		'MinPayments' => 1,
		'MinPaymentsForCredit' => 2,
		'UserKey' => $gateway->wppc_get_user_nonce(),
		'SetFocus' => $gateway->get_option( 'set_focus' ),
		'CssURL' => $gateway->get_option( 'css_url' ),
		'TopText' => $gateway->get_option( 'top_text' ),
		'BottomText' => $gateway->get_option( 'bottom_text' ),
		'LogoURL' => $gateway->get_option( 'logo_url' ),
		'ShowConfirmationCheckbox' => $gateway->get_option( 'confirmation_cb' ),
		'TextOnConfirmationBox' => $gateway->get_option( 'confirmation_text' ),
		'ConfirmationLink' => $gateway->get_option( 'confirmation_url' ),
		'HiddenPelecardLogo' => 'no' === $gateway->get_option( 'hidden_pelecard_logo' ),
		'SupportedCards' => $gateway->wppc_supported_cards(),
		'UserData' => [
			'UserData1' => get_current_user_id(),
			'UserData2' => wc_get_endpoint_url( 'payment-methods' ),
		],
		'CaptionSet' => [
			'cs_submit' => __( 'Add Card', 'wc-pelecard-gateway' ),
		],
	], $gateway );

	return request_iframe_url( $args );
}




function charge_by_token( WC_Order $order, Gateway $gateway, WC_Payment_Token_CC $token ) {
	$args = [
		'terminalNumber' => $gateway->wppc_terminal( true ),
		'user' => $gateway->wppc_username( true ),
		'password' => $gateway->wppc_password( true ),
		'token' => $token->get_token(),
		'total' => $order->get_total() * 100,
		'currency' => get_currency( $order ),
		'paramX' => $order->get_id(),
		'UserKey' => $order->get_order_key(),
	];

	$service = 'J5' === $gateway->wppc_get_action_type()
		? 'AuthorizeCreditCard'
		: 'DebitRegularType';

	$total_payments = $gateway->wppc_get_total_payments();
	if ( $total_payments > 1 ) {
		$args['paymentsNumber'] = $total_payments;

		if ( 'J5' === $gateway->wppc_get_action_type() ) {
			$service = 'AuthorizePaymentsType';
		} else {
			$service = $total_payments < $gateway->wppc_minimum_credit_payments()
				? 'DebitPaymentsType'
				: 'DebitCreditType';
		}
	}

	// @todo: if refund, don't send auth number
	$auth_number = $order->get_meta( '_wppc_auth_number' );
	if ( ! empty( $auth_number ) ) {
		$args['authorizationNumber'] = $auth_number;
	}

	// 3DSecure params
	$three_d_secure_params = Order::get_3ds_params( $order );
	if ( ! empty( $three_d_secure_params ) ) {
		$args['Eci'] = $three_d_secure_params[0];
		$args['XID'] = $three_d_secure_params[1];
		$args['Cavv'] = $three_d_secure_params[2];
	}

	Log::info( sprintf( 'CHARGE WITH TOKEN (%s)', $gateway->wppc_get_action_type() ) );
	if ( 0 < $order->get_id() ) {
		Log::info( sprintf( 'ORDER #%d: PAYMENT START', $order->get_id() ) );
	}

	$args = apply_filters( 'wppc/checkout/rest_args', $args, $order, $gateway, $token, $service );

	$response = request( "services/{$service}", $args );

	if ( is_wp_error( $response ) ) {
		Log::error( $response->get_error_message() );

		return $response;
	}

	return $response;
}
function validate_by_unique_key( string $confirmation_key, string $debit_total, string $unique_key ): bool {
	$args = [
		'ConfirmationKey' => $confirmation_key,
		'TotalX100' => $debit_total,
		'UniqueKey' => $unique_key,
	];

	$response = request( 'PaymentGW/ValidateByUniqueKey', $args );
	if ( is_wp_error( $response ) ) {
		return false;
	}

	return (bool) $response;
}
function get_transaction_by_id( string $transaction_id ) {
	$gateway = Gateway::instance();

	$args = [
		'terminal' => $gateway->wppc_terminal(),
		'user' => $gateway->wppc_username(),
		'password' => $gateway->wppc_password(),
		'TransactionId' => $transaction_id,
	];

	return request( 'PaymentGW/GetTransaction', $args );
}