<?php
use Pelecardwc\Log;

function request_iframe_url( $args ) {
	$response = request( 'PaymentGW/init', $args );

	// HTTP errors
	if ( is_wp_error( $response ) ) {
		return $response;
	}

	// API errors
	$api_errors = array_filter( $response['Error'] ?? [] );
	if ( empty( $response['URL'] ) && ! empty( $api_errors ) ) {
		return new WP_Error( $api_errors['ErrCode'], $api_errors['ErrMsg'] );
	}

	return $response['URL'];
}
function request( string $endpoint, array $data ) {
	$url = 'https://gateway20.pelecard.biz/' . $endpoint;
	$request_body = apply_filters( 'wppc/api/request_body', $data, $endpoint );

	$args = apply_filters( 'wppc/api/request_args', [
		'body' => json_encode( $request_body ),
		'user-agent' => 'WooCommerce ' . WC()->version,
		'timeout' => 30,
	] );

	Log::info( 'POST REQUEST: ' . $url );
	Log::debug( $request_body );

	$response = wp_remote_post( $url, $args );

	if ( is_wp_error( $response ) ) {
		Log::error( 'POST RESPONSE - ERROR' );
		Log::error( $response->get_error_message() );

		return $response;
	}

	$body = wp_remote_retrieve_body( $response );
	$result = json_decode( $body, true );

	if ( is_null( $result ) ) {
		return new WP_Error(
			'error_occurred',
			__( 'Sorry, an error occurred while processing your request.', 'wc-pelecard-gateway' )
		);
	}

	Log::info( 'POST RESPONSE - SUCCESS' );
	Log::debug( $result );

	return $result;
}
?>