<?php

namespace Pelecardwc\Invoices;

use Pelecardwc\Gateway;
use WC_Order;

/**
 * Class Base
 */
abstract class Base {

	public static $provider;

	protected function __construct() {
		add_action( 'plugins_loaded', [ $this, 'register_hooks' ] );
		add_filter( 'wppc/settings/admin_fields', [ $this, 'get_admin_fields' ], 20 );
	}

	public function register_hooks() {
		if ( $this->is_enabled() ) {
			add_filter( 'wppc/checkout/rest_args', [ $this, 'maybe_add_invoice_args' ], 10, 3 );
			add_filter( 'wppc/checkout/iframe_args', [ $this, 'maybe_add_invoice_args' ], 10, 3 );
		}
	}

	public function is_enabled(): bool {
		return 'yes' === $this->get_option( static::$provider );
	}

	public function get_option( string $key, $empty_value = null ) {
		return Gateway::instance()->get_option( $key, $empty_value );
	}

	public function get_formatted_items( WC_Order $order ): array {
		$items = [];

		list( $name, $total, $quantity ) = static::$item_scheme;

		foreach ( $order->get_items() as $item ) {
			$total_with_tax = (
				(float) $item->get_total() + (float) $item->get_total_tax()
			) / $item->get_quantity();

			$items[] = apply_filters( 'wppc/invoices/' . static::$provider . '_formatted_item', [
				$name => $item->get_name(),
				$total => $total_with_tax * 100,
				$quantity => $item->get_quantity(),
			], $item );
		}

		$shipping_total = (float) $order->get_shipping_total();
		if ( 0 < $shipping_total ) {
			$items[] = [
				$name => $order->get_shipping_method(),
				$total => $shipping_total * 100,
				$quantity => 1,
			];
		}

		return apply_filters( 'wppc/invoices/' . static::$provider . '_formatted_items', $items, $order );
	}

	public function apply_checkout_filters( array $args, WC_Order $order ): array {
		return apply_filters( 'wppc/invoices/' . static::$provider . '_checkout_args', $args, $order );
	}

	public function maybe_add_invoice_args( array $args, WC_Order $order, Gateway $gateway ) {
        if ( 'J4' !== $gateway->wppc_get_action_type() ) {
            return $args;
        }
        return $this->get_checkout_args( $args, $order );
    }

	abstract public function get_admin_fields( array $fields ): array;

	abstract public function get_checkout_args( array $args, WC_Order $order ): array;
}
