<?php

namespace Pelecardwc;

use DirectoryIterator;
use Pelecardwc\Traits\Singleton;
use ReflectionClass;
use ReflectionException;
include 'Api.php';
/**
 * Class Plugin
 */
class Plugin {

	use Singleton;

	public static $version = '1.0.0';

	private function __construct() {
		add_action( 'plugins_loaded', [ $this, 'register_hooks' ] );
		add_action( 'wp_enqueue_scripts', [ $this, 'enqueue_front_scripts' ], 20 );
		add_filter( 'woocommerce_payment_gateways', [ $this, 'wppc_add_payment_gateway' ], 10, 1 );

		Order::instance();
		Legacy::instance();

		$this->load( 'Invoices' );
	}

	public function load( string $directory ) {
		$iterator = new DirectoryIterator( __DIR__ . DIRECTORY_SEPARATOR . $directory );

		foreach ( $iterator as $file ) {
			if ( ! $file->isFile() ) {
				continue;
			}

			if ( 'php' !== ( $extension = $file->getExtension() ) ) {
				continue;
			}

			$basename = $file->getBasename( '.' . $extension );
			$class = __NAMESPACE__ . '\\' . $directory . '\\' . $basename;

			if ( ! $this->class_has_method( $class, 'instance' ) ) {
				continue;
			}

			$class::instance();
		}
	}

	public function class_has_method( string $class, string $method ): bool {
		try {
			return ( new ReflectionClass( $class ) )->hasMethod( $method );
		} catch ( ReflectionException $e ) {
			return false;
		}
	}

	public static function get_templates_path(): string {
		return self::get_directory_path() . '/templates/';
	}

	public static function get_directory_path(): string {
		return untrailingslashit( plugin_dir_path( wppc_FILE ) );
	}

	public static function get_directory_url(): string {
		return untrailingslashit( plugin_dir_url( wppc_FILE ) );
	}

	public static function get_migrations_path( string $migration ): string {
		return self::get_directory_path() . '/migrations/' . $migration;
	}

	public function register_hooks() {
		add_action( 'wp', [ Gateway::instance(), 'wppc_maybe_process_redirect_order' ] );
	}

	public function wppc_add_payment_gateway( array $gateways ): array {
		$gateways[] = Gateway::instance();

		return $gateways;
	}

	public function enqueue_front_scripts() {
		$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		wp_enqueue_script(
			'wppc-checkout',
			self::get_directory_url() . '/assets/js/checkout' . $suffix . '.js',
			[ 'jquery' ],
			self::$version
		);
	}
}
